Class: KatapultAPI::Organization
- Inherits:
-
Object
- Object
- KatapultAPI::Organization
- Defined in:
- lib/katapult-ruby/models/organization.rb
Instance Attribute Summary collapse
-
#address1 ⇒ Object
Returns the value of attribute address1.
-
#address2 ⇒ Object
Returns the value of attribute address2.
-
#address3 ⇒ Object
Returns the value of attribute address3.
-
#address4 ⇒ Object
Returns the value of attribute address4.
-
#billing_name ⇒ Object
Returns the value of attribute billing_name.
-
#country ⇒ Object
Returns the value of attribute country.
-
#country_state ⇒ Object
Returns the value of attribute country_state.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#id ⇒ Object
Returns the value of attribute id.
-
#infrastructure_domain ⇒ Object
Returns the value of attribute infrastructure_domain.
-
#managed ⇒ Object
Returns the value of attribute managed.
-
#name ⇒ Object
Returns the value of attribute name.
-
#phone_number ⇒ Object
Returns the value of attribute phone_number.
-
#postcode ⇒ Object
Returns the value of attribute postcode.
-
#sub_domain ⇒ Object
Returns the value of attribute sub_domain.
-
#suspended ⇒ Object
Returns the value of attribute suspended.
-
#vat_number ⇒ Object
Returns the value of attribute vat_number.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Organization
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Organization
Initializes the object
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/katapult-ruby/models/organization.rb', line 125 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `KatapultAPI::Organization` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `KatapultAPI::Organization`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'sub_domain') self.sub_domain = attributes[:'sub_domain'] end if attributes.key?(:'infrastructure_domain') self.infrastructure_domain = attributes[:'infrastructure_domain'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'suspended') self.suspended = attributes[:'suspended'] end if attributes.key?(:'managed') self.managed = attributes[:'managed'] end if attributes.key?(:'billing_name') self.billing_name = attributes[:'billing_name'] end if attributes.key?(:'address1') self.address1 = attributes[:'address1'] end if attributes.key?(:'address2') self.address2 = attributes[:'address2'] end if attributes.key?(:'address3') self.address3 = attributes[:'address3'] end if attributes.key?(:'address4') self.address4 = attributes[:'address4'] end if attributes.key?(:'postcode') self.postcode = attributes[:'postcode'] end if attributes.key?(:'vat_number') self.vat_number = attributes[:'vat_number'] end if attributes.key?(:'phone_number') self.phone_number = attributes[:'phone_number'] end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'country_state') self.country_state = attributes[:'country_state'] end end |
Instance Attribute Details
#address1 ⇒ Object
Returns the value of attribute address1.
34 35 36 |
# File 'lib/katapult-ruby/models/organization.rb', line 34 def address1 @address1 end |
#address2 ⇒ Object
Returns the value of attribute address2.
36 37 38 |
# File 'lib/katapult-ruby/models/organization.rb', line 36 def address2 @address2 end |
#address3 ⇒ Object
Returns the value of attribute address3.
38 39 40 |
# File 'lib/katapult-ruby/models/organization.rb', line 38 def address3 @address3 end |
#address4 ⇒ Object
Returns the value of attribute address4.
40 41 42 |
# File 'lib/katapult-ruby/models/organization.rb', line 40 def address4 @address4 end |
#billing_name ⇒ Object
Returns the value of attribute billing_name.
32 33 34 |
# File 'lib/katapult-ruby/models/organization.rb', line 32 def billing_name @billing_name end |
#country ⇒ Object
Returns the value of attribute country.
50 51 52 |
# File 'lib/katapult-ruby/models/organization.rb', line 50 def country @country end |
#country_state ⇒ Object
Returns the value of attribute country_state.
52 53 54 |
# File 'lib/katapult-ruby/models/organization.rb', line 52 def country_state @country_state end |
#created_at ⇒ Object
Returns the value of attribute created_at.
26 27 28 |
# File 'lib/katapult-ruby/models/organization.rb', line 26 def created_at @created_at end |
#currency ⇒ Object
Returns the value of attribute currency.
48 49 50 |
# File 'lib/katapult-ruby/models/organization.rb', line 48 def currency @currency end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/katapult-ruby/models/organization.rb', line 18 def id @id end |
#infrastructure_domain ⇒ Object
Returns the value of attribute infrastructure_domain.
24 25 26 |
# File 'lib/katapult-ruby/models/organization.rb', line 24 def infrastructure_domain @infrastructure_domain end |
#managed ⇒ Object
Returns the value of attribute managed.
30 31 32 |
# File 'lib/katapult-ruby/models/organization.rb', line 30 def managed @managed end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/katapult-ruby/models/organization.rb', line 20 def name @name end |
#phone_number ⇒ Object
Returns the value of attribute phone_number.
46 47 48 |
# File 'lib/katapult-ruby/models/organization.rb', line 46 def phone_number @phone_number end |
#postcode ⇒ Object
Returns the value of attribute postcode.
42 43 44 |
# File 'lib/katapult-ruby/models/organization.rb', line 42 def postcode @postcode end |
#sub_domain ⇒ Object
Returns the value of attribute sub_domain.
22 23 24 |
# File 'lib/katapult-ruby/models/organization.rb', line 22 def sub_domain @sub_domain end |
#suspended ⇒ Object
Returns the value of attribute suspended.
28 29 30 |
# File 'lib/katapult-ruby/models/organization.rb', line 28 def suspended @suspended end |
#vat_number ⇒ Object
Returns the value of attribute vat_number.
44 45 46 |
# File 'lib/katapult-ruby/models/organization.rb', line 44 def vat_number @vat_number end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/katapult-ruby/models/organization.rb', line 290 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = KatapultAPI.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/katapult-ruby/models/organization.rb', line 79 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/katapult-ruby/models/organization.rb', line 55 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'sub_domain' => :'sub_domain', :'infrastructure_domain' => :'infrastructure_domain', :'created_at' => :'created_at', :'suspended' => :'suspended', :'managed' => :'managed', :'billing_name' => :'billing_name', :'address1' => :'address1', :'address2' => :'address2', :'address3' => :'address3', :'address4' => :'address4', :'postcode' => :'postcode', :'vat_number' => :'vat_number', :'phone_number' => :'phone_number', :'currency' => :'currency', :'country' => :'country', :'country_state' => :'country_state' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/katapult-ruby/models/organization.rb', line 266 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/katapult-ruby/models/organization.rb', line 108 def self.openapi_nullable Set.new([ :'billing_name', :'address1', :'address2', :'address3', :'address4', :'postcode', :'vat_number', :'phone_number', :'country', :'country_state' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/katapult-ruby/models/organization.rb', line 84 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'sub_domain' => :'String', :'infrastructure_domain' => :'String', :'created_at' => :'Integer', :'suspended' => :'Boolean', :'managed' => :'Boolean', :'billing_name' => :'String', :'address1' => :'String', :'address2' => :'String', :'address3' => :'String', :'address4' => :'String', :'postcode' => :'String', :'vat_number' => :'String', :'phone_number' => :'String', :'currency' => :'Currency', :'country' => :'Country', :'country_state' => :'CountryState' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/katapult-ruby/models/organization.rb', line 228 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && sub_domain == o.sub_domain && infrastructure_domain == o.infrastructure_domain && created_at == o.created_at && suspended == o.suspended && managed == o.managed && billing_name == o.billing_name && address1 == o.address1 && address2 == o.address2 && address3 == o.address3 && address4 == o.address4 && postcode == o.postcode && vat_number == o.vat_number && phone_number == o.phone_number && currency == o.currency && country == o.country && country_state == o.country_state end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/katapult-ruby/models/organization.rb', line 361 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
253 254 255 |
# File 'lib/katapult-ruby/models/organization.rb', line 253 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
259 260 261 |
# File 'lib/katapult-ruby/models/organization.rb', line 259 def hash [id, name, sub_domain, infrastructure_domain, created_at, suspended, managed, billing_name, address1, address2, address3, address4, postcode, vat_number, phone_number, currency, country, country_state].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
213 214 215 216 217 |
# File 'lib/katapult-ruby/models/organization.rb', line 213 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
337 338 339 |
# File 'lib/katapult-ruby/models/organization.rb', line 337 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/katapult-ruby/models/organization.rb', line 343 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
331 332 333 |
# File 'lib/katapult-ruby/models/organization.rb', line 331 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
221 222 223 224 |
# File 'lib/katapult-ruby/models/organization.rb', line 221 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |