Method: KatapultAPI::RecordContentAttributesForSSHFP#initialize
- Defined in:
- lib/katapult-ruby/models/record_content_attributes_for_sshfp.rb
#initialize(attributes = {}) ⇒ RecordContentAttributesForSSHFP
Initializes the object
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/katapult-ruby/models/record_content_attributes_for_sshfp.rb', line 55 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `KatapultAPI::RecordContentAttributesForSSHFP` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `KatapultAPI::RecordContentAttributesForSSHFP`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'algorithm') self.algorithm = attributes[:'algorithm'] end if attributes.key?(:'fingerprint_type') self.fingerprint_type = attributes[:'fingerprint_type'] end if attributes.key?(:'fingerprint') self.fingerprint = attributes[:'fingerprint'] end end |