Method: KatapultAPI::TaskQueueingErrorSchema#initialize
- Defined in:
- lib/katapult-ruby/models/task_queueing_error_schema.rb
#initialize(attributes = {}) ⇒ TaskQueueingErrorSchema
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/katapult-ruby/models/task_queueing_error_schema.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `KatapultAPI::TaskQueueingErrorSchema` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `KatapultAPI::TaskQueueingErrorSchema`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'code') self.code = attributes[:'code'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'detail') self.detail = attributes[:'detail'] end end |